==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SignatureIdentifierType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SignatureIdentifierType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SignatureIdentifierType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="showSignedBy" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showCommonName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showOrganisationUnit" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showOrganisationName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showLocal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showState" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showCountry" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showMail" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="showDate" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SignatureIdentifierType")
public class SignatureIdentifierType {

    @XmlAttribute(name = "showSignedBy")
    protected Boolean showSignedBy;
    @XmlAttribute(name = "showName")
    protected Boolean showName;
    @XmlAttribute(name = "showCommonName")
    protected Boolean showCommonName;
    @XmlAttribute(name = "showOrganisationUnit")
    protected Boolean showOrganisationUnit;
    @XmlAttribute(name = "showOrganisationName")
    protected Boolean showOrganisationName;
    @XmlAttribute(name = "showLocal")
    protected Boolean showLocal;
    @XmlAttribute(name = "showState")
    protected Boolean showState;
    @XmlAttribute(name = "showCountry")
    protected Boolean showCountry;
    @XmlAttribute(name = "showMail")
    protected Boolean showMail;
    @XmlAttribute(name = "showDate")
    protected Boolean showDate;

    /**
     * Gets the value of the showSignedBy property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowSignedBy() {
        if (showSignedBy == null) {
            return true;
        } else {
            return showSignedBy;
        }
    }

    /**
     * Sets the value of the showSignedBy property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowSignedBy(boolean value) {
        this.showSignedBy = value;
    }

    public boolean isSetShowSignedBy() {
        return (this.showSignedBy!= null);
    }

    public void unsetShowSignedBy() {
        this.showSignedBy = null;
    }

    /**
     * Gets the value of the showName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowName() {
        if (showName == null) {
            return true;
        } else {
            return showName;
        }
    }

    /**
     * Sets the value of the showName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowName(boolean value) {
        this.showName = value;
    }

    public boolean isSetShowName() {
        return (this.showName!= null);
    }

    public void unsetShowName() {
        this.showName = null;
    }

    /**
     * Gets the value of the showCommonName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCommonName() {
        if (showCommonName == null) {
            return true;
        } else {
            return showCommonName;
        }
    }

    /**
     * Sets the value of the showCommonName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCommonName(boolean value) {
        this.showCommonName = value;
    }

    public boolean isSetShowCommonName() {
        return (this.showCommonName!= null);
    }

    public void unsetShowCommonName() {
        this.showCommonName = null;
    }

    /**
     * Gets the value of the showOrganisationUnit property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowOrganisationUnit() {
        if (showOrganisationUnit == null) {
            return true;
        } else {
            return showOrganisationUnit;
        }
    }

    /**
     * Sets the value of the showOrganisationUnit property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowOrganisationUnit(boolean value) {
        this.showOrganisationUnit = value;
    }

    public boolean isSetShowOrganisationUnit() {
        return (this.showOrganisationUnit!= null);
    }

    public void unsetShowOrganisationUnit() {
        this.showOrganisationUnit = null;
    }

    /**
     * Gets the value of the showOrganisationName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowOrganisationName() {
        if (showOrganisationName == null) {
            return true;
        } else {
            return showOrganisationName;
        }
    }

    /**
     * Sets the value of the showOrganisationName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowOrganisationName(boolean value) {
        this.showOrganisationName = value;
    }

    public boolean isSetShowOrganisationName() {
        return (this.showOrganisationName!= null);
    }

    public void unsetShowOrganisationName() {
        this.showOrganisationName = null;
    }

    /**
     * Gets the value of the showLocal property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowLocal() {
        if (showLocal == null) {
            return true;
        } else {
            return showLocal;
        }
    }

    /**
     * Sets the value of the showLocal property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowLocal(boolean value) {
        this.showLocal = value;
    }

    public boolean isSetShowLocal() {
        return (this.showLocal!= null);
    }

    public void unsetShowLocal() {
        this.showLocal = null;
    }

    /**
     * Gets the value of the showState property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowState() {
        if (showState == null) {
            return true;
        } else {
            return showState;
        }
    }

    /**
     * Sets the value of the showState property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowState(boolean value) {
        this.showState = value;
    }

    public boolean isSetShowState() {
        return (this.showState!= null);
    }

    public void unsetShowState() {
        this.showState = null;
    }

    /**
     * Gets the value of the showCountry property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCountry() {
        if (showCountry == null) {
            return true;
        } else {
            return showCountry;
        }
    }

    /**
     * Sets the value of the showCountry property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCountry(boolean value) {
        this.showCountry = value;
    }

    public boolean isSetShowCountry() {
        return (this.showCountry!= null);
    }

    public void unsetShowCountry() {
        this.showCountry = null;
    }

    /**
     * Gets the value of the showMail property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowMail() {
        if (showMail == null) {
            return true;
        } else {
            return showMail;
        }
    }

    /**
     * Sets the value of the showMail property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowMail(boolean value) {
        this.showMail = value;
    }

    public boolean isSetShowMail() {
        return (this.showMail!= null);
    }

    public void unsetShowMail() {
        this.showMail = null;
    }

    /**
     * Gets the value of the showDate property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowDate() {
        if (showDate == null) {
            return true;
        } else {
            return showDate;
        }
    }

    /**
     * Sets the value of the showDate property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowDate(boolean value) {
        this.showDate = value;
    }

    public boolean isSetShowDate() {
        return (this.showDate!= null);
    }

    public void unsetShowDate() {
        this.showDate = null;
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/SignatureIdentifierType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p742589_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p960539_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to define the elements that are part of the visual signature.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SignatureIdentifierType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SignatureIdentifierType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="showSignedBy" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showCommonName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showOrganisationUnit" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showOrganisationName" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showLocal" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showState" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showCountry" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showMail" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="showDate" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="textSignedBy" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SignatureIdentifierType")
public class SignatureIdentifierType {

    @XmlAttribute(name = "showSignedBy")
    protected Boolean showSignedBy;
    @XmlAttribute(name = "showName")
    protected Boolean showName;
    @XmlAttribute(name = "showCommonName")
    protected Boolean showCommonName;
    @XmlAttribute(name = "showOrganisationUnit")
    protected Boolean showOrganisationUnit;
    @XmlAttribute(name = "showOrganisationName")
    protected Boolean showOrganisationName;
    @XmlAttribute(name = "showLocal")
    protected Boolean showLocal;
    @XmlAttribute(name = "showState")
    protected Boolean showState;
    @XmlAttribute(name = "showCountry")
    protected Boolean showCountry;
    @XmlAttribute(name = "showMail")
    protected Boolean showMail;
    @XmlAttribute(name = "showDate")
    protected Boolean showDate;
    @XmlAttribute(name = "textSignedBy")
    protected String textSignedBy;

    /**
     * Gets the value of the showSignedBy property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowSignedBy() {
        if (showSignedBy == null) {
            return true;
        } else {
            return showSignedBy;
        }
    }

    /**
     * Sets the value of the showSignedBy property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowSignedBy(boolean value) {
        this.showSignedBy = value;
    }

    public boolean isSetShowSignedBy() {
        return (this.showSignedBy!= null);
    }

    public void unsetShowSignedBy() {
        this.showSignedBy = null;
    }

    /**
     * Gets the value of the showName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowName() {
        if (showName == null) {
            return true;
        } else {
            return showName;
        }
    }

    /**
     * Sets the value of the showName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowName(boolean value) {
        this.showName = value;
    }

    public boolean isSetShowName() {
        return (this.showName!= null);
    }

    public void unsetShowName() {
        this.showName = null;
    }

    /**
     * Gets the value of the showCommonName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCommonName() {
        if (showCommonName == null) {
            return true;
        } else {
            return showCommonName;
        }
    }

    /**
     * Sets the value of the showCommonName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCommonName(boolean value) {
        this.showCommonName = value;
    }

    public boolean isSetShowCommonName() {
        return (this.showCommonName!= null);
    }

    public void unsetShowCommonName() {
        this.showCommonName = null;
    }

    /**
     * Gets the value of the showOrganisationUnit property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowOrganisationUnit() {
        if (showOrganisationUnit == null) {
            return true;
        } else {
            return showOrganisationUnit;
        }
    }

    /**
     * Sets the value of the showOrganisationUnit property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowOrganisationUnit(boolean value) {
        this.showOrganisationUnit = value;
    }

    public boolean isSetShowOrganisationUnit() {
        return (this.showOrganisationUnit!= null);
    }

    public void unsetShowOrganisationUnit() {
        this.showOrganisationUnit = null;
    }

    /**
     * Gets the value of the showOrganisationName property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowOrganisationName() {
        if (showOrganisationName == null) {
            return true;
        } else {
            return showOrganisationName;
        }
    }

    /**
     * Sets the value of the showOrganisationName property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowOrganisationName(boolean value) {
        this.showOrganisationName = value;
    }

    public boolean isSetShowOrganisationName() {
        return (this.showOrganisationName!= null);
    }

    public void unsetShowOrganisationName() {
        this.showOrganisationName = null;
    }

    /**
     * Gets the value of the showLocal property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowLocal() {
        if (showLocal == null) {
            return true;
        } else {
            return showLocal;
        }
    }

    /**
     * Sets the value of the showLocal property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowLocal(boolean value) {
        this.showLocal = value;
    }

    public boolean isSetShowLocal() {
        return (this.showLocal!= null);
    }

    public void unsetShowLocal() {
        this.showLocal = null;
    }

    /**
     * Gets the value of the showState property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowState() {
        if (showState == null) {
            return true;
        } else {
            return showState;
        }
    }

    /**
     * Sets the value of the showState property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowState(boolean value) {
        this.showState = value;
    }

    public boolean isSetShowState() {
        return (this.showState!= null);
    }

    public void unsetShowState() {
        this.showState = null;
    }

    /**
     * Gets the value of the showCountry property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowCountry() {
        if (showCountry == null) {
            return true;
        } else {
            return showCountry;
        }
    }

    /**
     * Sets the value of the showCountry property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowCountry(boolean value) {
        this.showCountry = value;
    }

    public boolean isSetShowCountry() {
        return (this.showCountry!= null);
    }

    public void unsetShowCountry() {
        this.showCountry = null;
    }

    /**
     * Gets the value of the showMail property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowMail() {
        if (showMail == null) {
            return true;
        } else {
            return showMail;
        }
    }

    /**
     * Sets the value of the showMail property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowMail(boolean value) {
        this.showMail = value;
    }

    public boolean isSetShowMail() {
        return (this.showMail!= null);
    }

    public void unsetShowMail() {
        this.showMail = null;
    }

    /**
     * Gets the value of the showDate property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isShowDate() {
        if (showDate == null) {
            return true;
        } else {
            return showDate;
        }
    }

    /**
     * Sets the value of the showDate property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setShowDate(boolean value) {
        this.showDate = value;
    }

    public boolean isSetShowDate() {
        return (this.showDate!= null);
    }

    public void unsetShowDate() {
        this.showDate = null;
    }

    /**
     * Gets the value of the textSignedBy property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTextSignedBy() {
        if (textSignedBy == null) {
            return "";
        } else {
            return textSignedBy;
        }
    }

    /**
     * Sets the value of the textSignedBy property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTextSignedBy(String value) {
        this.textSignedBy = value;
    }

    public boolean isSetTextSignedBy() {
        return (this.textSignedBy!= null);
    }

}
